#############
API Reference
#############


Central moments arrays
======================

.. currentmodule:: cmomy

.. autosummary::
   :toctree: generated/
   :template: custom-class.rst

   CentralMoments


.. autosummary::
   :toctree: generated/

   central_moments



Central moments from xarray.DataArray
=====================================


.. autosummary::
   :toctree: generated/
   :template: custom-class.rst

   xCentralMoments

.. autosummary::
   :toctree: generated/

   xcentral_moments


Resampling routines
===================

.. autosummary::
   :toctree: generated/

   resample.resample_vals
   resample.resample_data
   resample.randsamp_freq
   resample.freq_to_indices
   resample.bootstrap_confidence_interval
   resample.xbootstrap_confidence_interval


Convert to/from raw moments
===========================

.. autosummary::
   :toctree: generated/

   convert.to_central_moments
   convert.to_central_comoments
   convert.to_raw_moments
   convert.to_raw_comoments
